@@ -450,6 +450,7 @@
   (begin
     (d-MasterVolume DenemoVolume::Value)))
 
+(define DenemoPutMidi d-PutMidi) ;;hook for intercepting MIDI filter output
     
 (define (DenemoSetPlaybackStart)
     (d-Stop)
@@ -1473,3 +1474,41 @@
     (if (d-MoveToStaffDown) 
         (loop)))
 (d-PopPosition))      
+
+;;;;;
+(define (DenemoInsertChordTransposed notes root-note) ;; notes is a string e.g. "c e g" root-note is a symbol e.g 'cis,,
+    (let ((cursorNote #f)(above #f)(interval #f)(old_volume (d-MasterVolume)))
+      (d-MasterVolume 0)
+      (d-PutNote)
+      (d-MoveCursorLeft)
+      (set! cursorNote (string->symbol (d-GetNote)))
+      (d-DeleteObject)
+      (d-InsertChord notes)
+      (d-MoveCursorLeft)
+      (set! above (< (ANS::Ly2Ans cursorNote)  (ANS::Ly2Ans root-note)))
+      (set! interval (ANS::GetInterval  (ANS::Ly2Ans root-note)  (ANS::Ly2Ans cursorNote)))
+      (ANS::ChangeChordNotes (map (lambda (x) ((if above ANS::IntervalCalcDown ANS::IntervalCalcUp) x interval)) (ANS::GetChordNotes)))
+      (d-MasterVolume old_volume)
+      (d-PlayAtCursor)))       
+
+(define (DenemoGetNoteAndAccidental)
+    (define note (d-GetNote 1))
+    (define acc "")
+    (define name #f)
+    (if note
+        (begin
+            (set! name (string-upcase (substring note 0 1)))
+            (if (> (string-length note) 1)
+                (let ((char (string-ref note 1)))
+                    (if (eq? char #\e)
+                        (set! acc "♭")
+                        (if (eq? char #\i)
+                            (set! acc "♯")))))
+        (string-append name acc))
+        #f))
+
+(define* (DenemoGetUserNumberAsString #:optional (title "") (prompt "") (initial ""))
+    (let ((val (d-GetUserInput title prompt initial)))
+        (if (and val (string->number val))
+            val
+            #f)))
