@@ -51,7 +51,7 @@
                         (d-CheckTimeSignatures #t)
                         (set! CheckScore::return CheckTimeSignatures::return)))            
                                
-        (if (not CheckScore::return)
+        (if (and (not CheckScore::return) (not (d-Directive-layout? "PolymetricStaffs")))
               (begin
                 (while (d-MoveToStaffUp))  
                   (let staff ()
@@ -61,19 +61,19 @@
                             (d-MoveToBeginning)
                             (let measure ()
                                 (if (not (LastMeasure?)) 
-                            (if (or (FullDurationMeasure?)(ZeroDurationMeasure?))
-                                        (begin
-                                            (d-MoveToMeasureRight)
-                                            (measure))
-                                        (begin
-                                             (if (positive? CheckScore::ignore)
-                                                    (begin
-                                                        (set! CheckScore::ignore (1- CheckScore::ignore))
-                                                        (d-MoveToMeasureRight)
-                                                        (measure))
-                                                    (begin
-                                                        (set! CheckScore::return (_ "Incorrect measure duration"))
-                                                        (set! CheckScore::error-position (GetPosition))))))))
+		                    (if (AcceptableDurationMeasure?)
+		                                (begin
+		                                    (d-MoveToMeasureRight)
+		                                    (measure))
+		                                (begin
+		                                     (if (positive? CheckScore::ignore)
+		                                            (begin
+		                                                (set! CheckScore::ignore (1- CheckScore::ignore))
+		                                                (d-MoveToMeasureRight)
+		                                                (measure))
+		                                            (begin
+		                                                (set! CheckScore::return (_ "Incorrect measure duration"))
+		                                                (set! CheckScore::error-position (GetPosition))))))))
                             (if (not CheckScore::return)
                                 (begin
                                    
