@@ -611,7 +611,7 @@ midiaction (gint notenum)
                 {
                   curObj = Denemo.project->movement->currentobject->data;
                   chord *thechord = (chord *) curObj->object;
-                  is_tied = thechord->is_tied;
+                  is_tied = (!Denemo.prefs.ignore_ties) && thechord->is_tied;
 
 //#define check_midi_note(a,b,c,d) ((a->mid_c_offset==b)&&(a->enshift==c))?playnote(a,curstaffstruct->midi_channel):gdk_beep();
                   if ((Denemo.keyboard_state & CHECKING_MASK) && thechord->notes)
@@ -640,7 +640,7 @@ midiaction (gint notenum)
                     break;
                     curObj = Denemo.project->movement->currentobject->data;
                     thechord = (chord *) curObj->object;
-                    is_tied = thechord->is_tied;
+                    is_tied = (!Denemo.prefs.ignore_ties) && thechord->is_tied;
                 }
               while ((!(Denemo.keyboard_state & ADDING_MASK)) && next_editable_note () && is_tied);
             }
@@ -730,6 +730,13 @@ void add_after_touch (gchar * buf)
    if (Denemo.prefs.damping)
     {
       static gdouble times[0x7F]; //takes no account of channel, really only good for one channel.
+      //HACK IN kill pitch bend and "modulation" wheel here
+      if (command == MIDI_PITCH_BEND)
+        {g_print ("Dropping pitch bend\n"); *buf=0; return;} 
+      if (command == 0xB0)
+        {g_print ("Dropping controller change message\n"); *buf=0;  return;} 
+        
+        
       if (command == MIDI_NOTE_ON)
         {
           times[notenumber] = get_time ();
@@ -866,7 +873,7 @@ advance_until_time (gchar * buf)
                   gdouble thetime = get_time ();
                   Denemo.project->movement->start_player = thetime - obj->earliest_time;
 
-                  if (thechord->is_tied && cursor_to_next_note ())
+                  if ((!Denemo.prefs.ignore_ties) && thechord->is_tied && cursor_to_next_note ())
                     {
                       obj = Denemo.project->movement->currentobject->data;
                     }
