@@ -62,25 +62,7 @@ apply_fakechord (chord * ch, gchar * fig)
  * Get the fakechords if it has one
  *
  */
-/* UNUSED
-static GString *
-get_fakechord (chord * ch)
-{
-  DenemoObject *mud;
-  chord *mych;
-  if (!ch->fakechord)
-    {
-      g_warning ("No fakechord attached to this note - useless to edit it!");
-      return NULL;
-    }
-  g_assert (!ch->is_fakechord);
-  mud = (DenemoObject *) (((GList *) ch->fakechord)->data);
-  g_assert (mud);
-  mych = (chord *) mud->object;
-  g_assert (mych);
-  return (GString *) mych->fakechord;
-}
-*/
+
 void
 separate_fakechord_elements (gchar * fakechord, DenemoObject * curObj)
 {
@@ -175,12 +157,14 @@ delete_fakechords (GtkAction * action, DenemoScriptParam * param)
   if (confirm (_("Chord Symbol Deletion"), _("Delete all Chord Symbols from this staff?")))
     {
       thestaff->hasfakechords = FALSE;
+      gui->movement->has_fakechords = FALSE;
+
       score_status (gui, TRUE);
       measurenode *curmeasure;
-      for (curmeasure = thestaff->measures; curmeasure; curmeasure = curmeasure->next)
+      for (curmeasure = thestaff->themeasures; curmeasure; curmeasure = curmeasure->next)
         {
           objnode *curobj;
-          for (curobj = curmeasure->data; curobj; curobj = curobj->next)
+          for (curobj = ((DenemoMeasure*)curmeasure->data)->objects; curobj; curobj = curobj->next)
             {
               DenemoObject *curObj = (DenemoObject *) curobj->data;
               if (curObj && curObj->type == CHORD)
