@@ -149,16 +149,18 @@ void set_title_bar (DenemoProject * gui);
 void score_status (DenemoProject * gui, gboolean change);
 void write_status (DenemoProject * gui);
 gboolean confirm (gchar * primary, gchar * secondary);
+gboolean confirm_first_choice (gchar *title, gchar * primary, gchar * secondary);
 gboolean choose_option (gchar * title, gchar * primary, gchar * secondary);
 gint choose_option_or_cancel (gchar * title, gchar * primary, gchar * secondary, gboolean cancel_button);
 void nullify_gstring (GString ** s);
 gchar *choose_file (gchar * title, gchar * startdir, GList * extensions);
 gchar *string_dialog_entry (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value);
-
+gchar *notes_choice_dialog (gint number_of_notes /* 1 or 2 */, gchar *initial_value, gchar *meaning);
 gchar *string_dialog_entry_with_widget (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value, GtkWidget * extra_widget);
 gchar *string_dialog_editor_with_widget (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gpointer keypress_callback);
 gchar *string_dialog_entry_with_widget_opt (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal);
 gchar *string_dialog_editor_with_widget_opt (DenemoProject * gui, gchar * wlabel, gchar * direction, gchar * PreValue, GtkWidget * widget, gboolean modal, gpointer keypress_callback);
+gchar *get_multiline_input (gchar *title, gchar *instruction, gchar *initial);
 void note2lilynotename (struct note *noteobject, GString * ret);
 void note2lilyaccidental (struct note *noteobject, GString * ret);
 void note2lilyoctave (struct note *noteobject, GString * ret);
@@ -166,8 +168,7 @@ void chord2lilybaseduration (struct chord *chordobject, GString * ret);
 void chord2lilyduration (struct chord *chordobject, GString * ret);
 void chord2lilynumdots (struct chord *chordobject, GString * ret);
 gchar *get_fretdiagram_as_markup (void);
-gchar *get_fakechord_as_markup (gchar * size, gchar * font);
-
+gchar *get_chord_notes (void);
 
 #define UTILS_H_PARAM_ASSIGN(param_name) if( (str = g_strstr_len(values->str+i,strlen(values->str+i), #param_name)))\
 nothing=FALSE,param_name = (*(str+strlen(#param_name))=='=')?str+strlen(#param_name)+1:NULL;
