@@ -26,6 +26,7 @@
 
 #include "export/print.h"
 #include "printview/printview.h"
+#include "printview/markupview.h"
 #include "core/prefops.h"
 #include "export/exportlilypond.h"
 #include "core/utils.h"
@@ -685,21 +686,8 @@ void create_pdf_for_lilypond (gchar *lilypond)
 #ifndef USE_EVINCE
           g_debug("This feature requires denemo to be built with evince");
 #else
-         if (Denemo.printstatus->printpid != GPID_NONE)
-    {
-      if (confirm (_("Already Typesetting"), _("Abandon this typeset?")))
-        {
-          if (Denemo.printstatus->printpid != GPID_NONE)        //It could have died while the user was making up their mind...
-            kill_process (Denemo.printstatus->printpid);
-          Denemo.printstatus->printpid = GPID_NONE;
-        }
-      else
-        {
-          warningdialog (_("Cancelled"));
-
-          return;
-        }
-    }
+    if (Denemo.printstatus->printpid != GPID_NONE)
+         return;
   get_wysiwyg_info()->stage = STAGE_NONE;
   advance_printname ();
   gchar *filename = Denemo.printstatus->printbasename[Denemo.printstatus->cycle];
@@ -709,7 +697,7 @@ void create_pdf_for_lilypond (gchar *lilypond)
   Denemo.printstatus->invalid = 0;
   g_free (Denemo.printstatus->error_file);Denemo.printstatus->error_file = NULL;
   run_lilypond_for_pdf (filename, lilyfile);
-  g_child_watch_add (Denemo.printstatus->printpid, (GChildWatchFunc) printview_finished, (gpointer) (FALSE));
+  g_child_watch_add (Denemo.printstatus->printpid, (GChildWatchFunc) markupview_finished, (gpointer) (FALSE));
 #endif
 }
 /**
