@@ -104,6 +104,9 @@ SCM scheme_get_editing_time (void);
 SCM scheme_debug_object (SCM);
 SCM scheme_display_object (void);
 SCM scheme_destroy_scheme_init (void);
+SCM scheme_get_note_names_from_user (SCM number, SCM init, SCM message);
+SCM scheme_get_multiline_user_input (SCM title, SCM instruction, SCM initial);
+SCM scheme_get_lilypond_syntax_from_user (SCM title, SCM instruction, SCM prior, SCM post, SCM initial) ;
 SCM scheme_get_note_name (SCM);
 SCM scheme_insert_rest (SCM);
 SCM scheme_insert_chord (SCM lilypondnotes, SCM duration);
@@ -166,6 +169,8 @@ SCM scheme_next_chord_in_measure (SCM);
 SCM scheme_prev_chord_in_measure (SCM);
 SCM scheme_next_note (SCM);
 SCM scheme_prev_note (SCM);
+SCM scheme_scroll_left (void);
+SCM scheme_scroll_right (void);
 SCM scheme_create_snippet_from_object (SCM);
 SCM scheme_select_snippet (SCM);
 SCM scheme_insert_snippet (SCM, SCM);
@@ -191,7 +196,6 @@ SCM scheme_get_offset (void);
 SCM scheme_get_control_point (SCM);
 SCM scheme_get_curve (void);
 SCM scheme_get_positions (SCM);
-SCM scheme_http (SCM hname, SCM page, SCM other, SCM poststr);
 SCM scheme_goto_position (SCM movement, SCM staff, SCM measure, SCM object);
 SCM scheme_create_palette_button (SCM palette, SCM lbl, SCM tltp, SCM scrp);
 SCM scheme_set_palette_shape (SCM palette, SCM horizontal, SCM limit);
