@@ -142,6 +142,7 @@ insert_keysig (keysig_data * kdata)
 
   if (tokey != G_MININT)
     {
+      take_snapshot ();  
       if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (kdata->checkbutton)))
         {
           for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
@@ -338,6 +339,7 @@ key_change_initial (GtkAction * action, DenemoScriptParam * param)
           g_string_free (scheme_str, TRUE);
           if (valid)
             {
+              param->status = TRUE;
               dnm_setinitialkeysig (curstaffstruct, tokey, isminor);
               displayhelper (gui);
             }
