@@ -296,7 +296,7 @@ assign_cursor (guint state, guint cursor_num)
   guint *cursor_state = g_new (guint, 1);
   *cursor_state = state;
   //g_print("Storing cursor %d for state 0x%x in hash table %p\n", cursor_num, state, Denemo.map->cursors );
-  GdkCursor *cursor = gdk_cursor_new (cursor_num);
+  GdkCursor *cursor = gdk_cursor_new_for_display (gdk_display_get_default (), cursor_num);
   if (cursor)
     g_hash_table_insert (Denemo.map->cursors, cursor_state, cursor);
 }
@@ -310,7 +310,7 @@ set_cursor_for (guint state)
   if (cursor)
     gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), cursor);
   else
-    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
+    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
 }
 
 
@@ -450,6 +450,11 @@ static void extend_selection (DragDirection direction)
 gint
 scorearea_leave_event (GtkWidget * widget, GdkEventCrossing * event)
 {
+    if(Denemo.object_hovering_over)
+      {
+        Denemo.object_hovering_over = NULL;
+        gtk_widget_queue_draw(Denemo.scorearea);
+      }
     gint allocated_height = get_widget_height (Denemo.scorearea);
     gint allocated_width = get_widget_width (Denemo.scorearea);
   if (event->state & GDK_BUTTON1_MASK)
@@ -458,7 +463,7 @@ scorearea_leave_event (GtkWidget * widget, GdkEventCrossing * event)
        last_event_x = event->x_root;
        last_event_y = event->y_root;
     }
-  gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR)); //FIXME? does this take time/hog memory
+  gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR); //FIXME? does this take time/hog memory
   return FALSE;                 //allow other handlers (specifically the pitch entry one)
 }
 
@@ -489,6 +494,19 @@ scorearea_enter_event (GtkWidget * widget, GdkEventCrossing * event)
   return FALSE;                 //allow other handlers
 }
 
+static gint is_nearby (gint line_height, gint y) {
+    return !(abs (line_height-y)/Denemo.project->movement->zoom <4);
+    
+}
+
+static gint hidden_staff_line (gint line_height)
+    {
+        GList *found = g_list_find_custom (Denemo.hidden_staff_heights, GINT_TO_POINTER(line_height), (GCompareFunc)is_nearby);// if(found)g_print ("found %d for line height %d hidden line %d\t", found->data, line_height,1 + g_list_position (Denemo.hidden_staff_heights, found));
+        if (found)
+            return 1 + g_list_position (Denemo.hidden_staff_heights, found);
+        else return 0;
+    }
+    
 /**
  * Mouse motion callback
  *
@@ -497,10 +515,17 @@ gint
 scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
 {
   DenemoProject *gui = Denemo.project;
+  static gboolean hovering_over_hidden = FALSE;
   if (gui == NULL || gui->movement == NULL)
     return FALSE;
   if (Denemo.scorearea == NULL)
     return FALSE;
+    
+  // this would avoid an interesting "cursor follow the pointer" mode, which we don't use because you would not be able to move the mouse pointer away e.g. to choose a menu without the Denemo Cursor moving...
+  //if (selecting && lh_down && !Denemo.project->movement->markstaffnum)
+  // selecting = lh_down = 0; 
+  // it should never happen, so we don't need to guard against it.
+  
   gint allocated_height = get_widget_height (Denemo.scorearea);
   gint line_height = allocated_height * gui->movement->system_height;
   if(dragging_outside)
@@ -623,9 +648,9 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
     }
 
   if (line_height - ((int) event->y - 8) % line_height < 12)
-    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_SB_V_DOUBLE_ARROW));
+    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_SB_V_DOUBLE_ARROW);
   else
-    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
+    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
 
   transform_coords (&event->x, &event->y);
   //g_debug("Marked %d\n", gui->movement->markstaffnum);
@@ -672,7 +697,150 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
           /* redraw to show new cursor position  */
           draw_score_area();
         }
+     return TRUE;
     }
+    
+ {
+ gboolean oldm = Denemo.hovering_over_movement;   
+ gboolean oldla = Denemo.hovering_over_left_arrow;   
+ gboolean oldra= Denemo.hovering_over_right_arrow;   
+ gboolean oldmu = Denemo.hovering_over_margin_up;   
+ gboolean oldmd = Denemo.hovering_over_margin_down;   
+ gboolean oldb = Denemo.hovering_over_brace;
+ gboolean oldp = Denemo.hovering_over_partname;
+ gboolean oldc = Denemo.hovering_over_clef;
+ gboolean oldks = Denemo.hovering_over_keysharpen;
+ gboolean oldkf = Denemo.hovering_over_keyflatten;
+ gboolean oldt = Denemo.hovering_over_timesig;
+ Denemo.hovering_over_movement = FALSE;
+
+ 
+ Denemo.hovering_over_movement = Denemo.hovering_over_left_arrow = Denemo.hovering_over_right_arrow = Denemo.hovering_over_brace = Denemo.hovering_over_margin_up = Denemo.hovering_over_margin_down = Denemo.hovering_over_partname = Denemo.hovering_over_clef = Denemo.hovering_over_timesig = Denemo.hovering_over_keysharpen = Denemo.hovering_over_keyflatten = FALSE;
+
+ if (event->x<25 && event->y<25)
+      {
+            Denemo.hovering_over_movement = TRUE;
+      }
+ else {
+      if (event->x < gui->leftmargin)
+        {
+           if (gui->braces && (gui->movement->leftmeasurenum == 1) && ((Denemo.hovering_over_brace =  ((gui->leftmargin - event->x) <  BRACEWIDTH * g_list_length (gui->braces)))))
+            ; //do nothing more hovering over brace is set
+            else
+            {
+                gint offset = (gint) get_click_height (gui, event->y);
+                if (offset > 0 && (offset < STAFF_HEIGHT / 2))  
+                    Denemo.hovering_over_margin_up = TRUE;
+                else if (offset > 0 && (offset < STAFF_HEIGHT))
+                    Denemo.hovering_over_margin_down = TRUE;
+            }
+        }
+      else
+         {
+            gint key = gui->movement->maxkeywidth;
+            gint cmajor = key ? 0 : 5;   
+           
+            if (((gint) get_click_height (gui, event->y)<-10) && (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key))
+                 {   
+                    struct placement_info pi;
+                    if (event->y < 0)
+                        get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+                    else
+                        get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+
+                    if (pi.the_staff == NULL)
+                        return TRUE;  
+                    if (gui->movement->currentstaffnum == pi.staff_number)    
+                             Denemo.hovering_over_partname = TRUE;
+                 }
+            else  
+                { 
+           
+                if (event->x < (gui->leftmargin+35) - cmajor)
+                    {
+                        Denemo.hovering_over_clef = TRUE;
+                    }
+                else if (event->x < (gui->leftmargin+35) + key + cmajor)   
+                   {
+                       gint offset = (gint) get_click_height (gui, event->y);
+                       if (offset > 0 && (offset < STAFF_HEIGHT / 2))  
+                            Denemo.hovering_over_keysharpen = TRUE;
+                       else if (offset > 0 && (offset < STAFF_HEIGHT))
+                            Denemo.hovering_over_keyflatten = TRUE;
+                    }
+                else if (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key)
+                   Denemo.hovering_over_timesig = TRUE;       
+                }
+        }
+    }
+    
+ //Detect arrow left/right
+ {
+    struct placement_info pi;
+    if (event->y < 0)
+        get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+    else
+        get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+     if(pi.the_staff)
+        {
+          if ((gui->movement->leftmeasurenum > 1) && (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + gui->movement->maxkeywidth) && (event->x > gui->leftmargin))
+            {
+             Denemo.hovering_over_left_arrow = TRUE;
+            }
+          else if (pi.nextmeasure)
+            {
+              if ((pi.at_edge) && ((pi.the_obj==NULL) || ((pi.the_obj->next == NULL) && (pi.offend))))   
+                 Denemo.hovering_over_right_arrow = TRUE;
+             }
+        }
+ }   
+    
+    
+    
+    
+    
+    
+  if ((oldm != Denemo.hovering_over_movement) 
+  || (oldla != Denemo.hovering_over_left_arrow) 
+  || (oldra != Denemo.hovering_over_right_arrow) 
+  || (oldmu != Denemo.hovering_over_margin_up) 
+  || (oldmd != Denemo.hovering_over_margin_down)
+  || (oldb != Denemo.hovering_over_brace)
+  || (oldp != Denemo.hovering_over_partname)
+  || (oldc != Denemo.hovering_over_clef)
+  || (oldt != Denemo.hovering_over_timesig)
+  || (oldks != Denemo.hovering_over_keysharpen)
+  || (oldkf != Denemo.hovering_over_keyflatten))
+    gtk_widget_queue_draw(Denemo.scorearea);
+ }
+
+
+  struct placement_info pi;
+   if (event->y < 0)
+    get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+  else
+    get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
+  GList *old_obj = Denemo.object_hovering_over;
+  Denemo.object_hovering_over = pi.the_obj;
+  if (old_obj != Denemo.object_hovering_over)
+    gtk_widget_queue_draw (Denemo.scorearea);
+    
+    
+   
+    if( hidden_staff_line ((gint)(0.5 + event->y)))
+        {
+           //if (!hovering_over_hidden) something else keeps re-setting the cursor, so just force it
+                gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_TARGET);
+            hovering_over_hidden = TRUE;
+            
+        }
+    else
+        {
+            if (hovering_over_hidden)
+                gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
+            hovering_over_hidden = FALSE;
+        }
+    
 
   if (Denemo.project->midi_destination & MIDICONDUCT)
     {
@@ -733,7 +901,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
                     return TRUE;
                 } else
                 {
-                    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (left?GDK_SB_H_DOUBLE_ARROW:GDK_X_CURSOR));
+                    gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), left?Denemo.GDK_SB_H_DOUBLE_ARROW:Denemo.GDK_X_CURSOR);
                     left? (dragging_audio = TRUE) : (dragging_tempo = TRUE);
                      if (Denemo.prefs.learning)
                      left? MouseGestureShow(_("Left Drag Note Onset"), _("This moves the audio to synchronize the start with the score.\nYou can use the Leadin button for this too."),
@@ -752,6 +920,12 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
   transform_coords (&event->x, &event->y);
   //g_debug("after %f %f\n", event->x, event->y);
 
+    if (Denemo.hovering_over_movement)
+        {
+          call_out_to_guile ("(EditMovement)");  
+          return TRUE;
+        }
+
 
   gtk_widget_grab_focus (widget);
   gint key = gui->movement->maxkeywidth;
@@ -762,12 +936,48 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
 
   struct placement_info pi;
   pi.the_staff = NULL;
+
+//navigate to a hidden staff if on a hidden staff line  
+  {
+      gint theline = hidden_staff_line ((gint)(0.5 + event->y));
+      if (theline)
+        {
+            GList *this = gui->movement->thescore;
+            gint count = 0;
+            gint staffnum = 0;
+            while (this)
+                {
+                    DenemoStaff *thestaff = (DenemoStaff*)this->data;
+                    if (thestaff->hidden && (this != gui->movement->currentstaff))
+                        {
+                            count++;
+                            if (count == theline)
+                                {
+                                    staffnum = 1 + g_list_position (gui->movement->thescore, this); //g_print ("Looked for hidden line %d got staffnum %d\n", theline, staffnum);
+                                    break;
+                                }
+                        }
+                if (this)
+                    this = this->next;
+                }
+        //staffnum is the first of the hidden staffs belonging to the line theline 
+        
+        goto_movement_staff_obj (NULL, -1, staffnum, gui->movement->currentmeasurenum, 0, gui->lefts[line_num]);    
+        return TRUE;
+        }   
+  }
+    
+  
+  
   if (event->y < 0)
     get_placement_from_coordinates (&pi, event->x, 0, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
   else
     get_placement_from_coordinates (&pi, event->x, event->y, gui->lefts[line_num], gui->rights[line_num], gui->scales[line_num]);
   if (pi.the_staff == NULL)
     return TRUE;                //could not place the cursor
+    
+    
+    
   change_staff (gui->movement, pi.staff_number, pi.the_staff);
 
 
@@ -857,69 +1067,75 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
           "to the staff it is typeset on. Run the Staff/Voice property editor to adjust any inconsistencies."));
 
     }
+
   if ((((DenemoStaff *) gui->movement->currentstaff->data)->voicecontrol == DENEMO_PRIMARY) && (gui->movement->leftmeasurenum == 1) && (event->x > gui->leftmargin))
     {
-      if (event->x < (gui->leftmargin+35) - cmajor)
-        {
-        if (offset<-10)
+        
+        if ((offset<-10) && (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key))
             {
                 if (Denemo.prefs.learning)
-                MouseGestureShow(_("Left on Staff name."), _("This pops up the built-in staff properties. For other properties of the current staff see the staff menu or the tools icon before the clef."),
+                MouseGestureShow(_("Left on Part name."), _("This pops up the built-in staff properties. For other properties of the current staff see the staff menu or the tools icon before the clef."),
                   MouseGesture);
                 staff_properties_change_cb (NULL, NULL);
+                return TRUE;
             }
         else
-            {
-              if (Denemo.prefs.learning)
-                MouseGestureShow(_("Left on initial Clef."), _("This pops up the initial clef menu."),
-                  MouseGesture);
-              popup_menu ("/InitialClefEditPopup");
-            }
-          return TRUE;
-        }
-      else if (event->x < (gui->leftmargin+35) + key + cmajor)
         {
-          if (left)
+          if (event->x < (gui->leftmargin+35) - cmajor)
             {
-              if (offset > 0 && (offset < STAFF_HEIGHT / 2))
+
                 {
                   if (Denemo.prefs.learning)
-                    MouseGestureShow(_("Left Click on blue."), _("This adds one sharp."),
+                    MouseGestureShow(_("Left on initial Clef."), _("This pops up the initial clef menu."),
                       MouseGesture);
-                if ((gui->movement->currentmeasure->next==NULL)  || confirm (_("Initial Key Signature Change"), _("Sharpen Keysignature?")))
-                  call_out_to_guile ("(d-SharpenInitialKeysigs)");
+                  popup_menu ("/InitialClefEditPopup");
                 }
-              else if (offset > 0 && (offset < STAFF_HEIGHT))
+              return TRUE;
+            }
+          else if (event->x < (gui->leftmargin+35) + key + cmajor)
+            {
+              if (left)
+                {
+                  if (offset > 0 && (offset < STAFF_HEIGHT / 2))
+                    {
+                      if (Denemo.prefs.learning)
+                        MouseGestureShow(_("Left Click on blue."), _("This adds one sharp."),
+                          MouseGesture);
+                    if ((gui->movement->currentmeasure->next==NULL)  || confirm (_("Initial Key Signature Change"), _("Sharpen Keysignature?")))
+                      call_out_to_guile ("(d-SharpenInitialKeysigs)");
+                    }
+                  else if (offset > 0 && (offset < STAFF_HEIGHT))
+                    {
+                      if (Denemo.prefs.learning)
+                        MouseGestureShow(_("Left Click on red."), _("This adds one flat."),
+                          MouseGesture);
+                      if ((gui->movement->currentmeasure->next==NULL) || confirm (_("Initial Key Signature Change"), _("Flatten Keysignature?")))
+                        call_out_to_guile ("(d-FlattenInitialKeysigs)");
+                    }
+                }
+              else
                 {
                   if (Denemo.prefs.learning)
-                    MouseGestureShow(_("Left Click on red."), _("This adds one flat."),
-                      MouseGesture);
-                  if ((gui->movement->currentmeasure->next==NULL) || confirm (_("Initial Key Signature Change"), _("Flatten Keysignature?")))
-                    call_out_to_guile ("(d-FlattenInitialKeysigs)");
+                    MouseGestureShow(_("Right Click on key."), _("This pops up the key signature menu."),
+                        MouseGesture);
+                  popup_menu ("/InitialKeyEditPopup");
                 }
+              return TRUE;
             }
-          else
+          else if (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key)
             {
               if (Denemo.prefs.learning)
-                MouseGestureShow(_("Right Click on key."), _("This pops up the key signature menu."),
-                    MouseGesture);
-              popup_menu ("/InitialKeyEditPopup");
+                MouseGestureShow(_("Click on Time."), _("This pops up the time signature menu."),
+                        MouseGesture);
+              popup_menu ("/InitialTimeEditPopup");
+              return TRUE;
             }
-          return TRUE;
-        }
-      else if (event->x < (gui->leftmargin+35) + SPACE_FOR_TIME + key)
-        {
-          if (Denemo.prefs.learning)
-            MouseGestureShow(_("Click on Time."), _("This pops up the time signature menu."),
-                    MouseGesture);
-          popup_menu ("/InitialTimeEditPopup");
-          return TRUE;
         }
     }
 
   if (event->x < gui->leftmargin)
     {
-       if (gui->braces)
+       if (gui->braces && (gui->movement->leftmeasurenum == 1))
         {
                 gint width = BRACEWIDTH * g_list_length (gui->braces);
                 //gint count = (gui->leftmargin - event->x)/BRACEWIDTH;
@@ -931,24 +1147,27 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
                     if ((count>0) && (count <= g_list_length (gui->braces)))
                         {
                             DenemoBrace *brace = (DenemoBrace*)g_list_nth_data (gui->braces, count-1);
-                            gint choice = choose_option (_("Editing Staff Groups (Braces)"), _("Edit Start Brace"), _("Edit End Brace"));
-                            gint staffnum = choice?brace->startstaff:brace->endstaff;
-                            //g_print ("Count is %d for start at %d\n", count, staffnum);
-                            GtkWidget *menuitem = gtk_ui_manager_get_widget (Denemo.ui_manager, "/ObjectMenu/StaffMenu/StaffGroupings");
-                            goto_movement_staff_obj (NULL, -1, staffnum, 1, 0, 0);
-                            if (menuitem)
-                                if (choice)
-                                    gtk_menu_popup (GTK_MENU (gtk_menu_item_get_submenu (GTK_MENU_ITEM (menuitem))), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
-                                else
+                            gint choice = choose_option_or_cancel (_("Editing Staff Groups (Braces)"), _("Edit Start Brace"), _("Edit End Brace"), TRUE);
+                            if( choice>=0)
                                 {
-                                    if (staff_directive_get_tag ("BraceEnd"))
-                                        call_out_to_guile ("(d-BraceEnd)");
-                                    else
-                                        warningdialog (_( "This staff grouping has no End Brace so it finishes on the lowest staff. Use the Staffs/Voices->Staff Groupings menu to place an End Brace on the desired staff"));
-                                }
-                            //note the popup returns as soon as the menu is popped up, so we can't go back to the original position.
+                                    gint staffnum = choice?brace->startstaff:brace->endstaff;
+                                    //g_print ("Count is %d for start at %d\n", count, staffnum);
+                                    GtkWidget *menuitem = gtk_ui_manager_get_widget (Denemo.ui_manager, "/ObjectMenu/StaffMenu/StaffGroupings");
+                                    goto_movement_staff_obj (NULL, -1, staffnum, 1, 0, 0);
+                                    if (menuitem)
+                                        if (choice)
+                                            gtk_menu_popup (GTK_MENU (gtk_menu_item_get_submenu (GTK_MENU_ITEM (menuitem))), NULL, NULL, NULL, NULL, 0, GDK_CURRENT_TIME);
+                                        else
+                                        {
+                                            if (staff_directive_get_tag ("BraceEnd"))
+                                                call_out_to_guile ("(d-BraceEnd)");
+                                            else
+                                                warningdialog (_( "This staff grouping has no End Brace so it finishes on the lowest staff. Use the Staffs/Voices->Staff Groupings menu to place an End Brace on the desired staff"));
+                                        }
+                                    //note the popup returns as soon as the menu is popped up, so we can't go back to the original position.
 
-                        }
+                                }
+                            }
 
                     return TRUE;
                 }
@@ -965,7 +1184,7 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
                   if (Denemo.prefs.learning)
                     MouseGestureShow(_("Click on Staff Directives."), _("This pops up the staff directives menu for editing"),
                       MouseGesture);
-                  edit_staff_properties ();//gtk_menu_popup (((DenemoStaff *) gui->movement->currentstaff->data)->staffmenu, NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
+                  call_out_to_guile ("(EditStaff)"); //edit_staff_properties ();//gtk_menu_popup (((DenemoStaff *) gui->movement->currentstaff->data)->staffmenu, NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time ());
                 }
               return TRUE;
             }
@@ -1073,7 +1292,7 @@ scorearea_button_release (GtkWidget * widget, GdkEventButton * event)
   if(gui->movement->recording && (dragging_tempo || dragging_audio))
     {
             dragging_tempo = dragging_audio = FALSE;
-            gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR));       //FIXME? does this take time/hog memory
+            gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), Denemo.GDK_LEFT_PTR);       //FIXME? does this take time/hog memory
             return TRUE;
     }
   if (dragging_separator)
