@@ -19,7 +19,7 @@
  * update_hscrollbar should be called as a cleanup whenever
  * si->leftmeasurenum or si->rightmeasurenum may have been altered,
  *  e.g., by preceding calls to set_rightmeasurenum; or when the
- *  number of measures may have changed.  
+ *  number of measures may have changed.
  */
 void
 update_hscrollbar (DenemoProject * gui)
@@ -46,7 +46,7 @@ update_hscrollbar (DenemoProject * gui)
  *
  * For simplicity, this function treats nonprimary voices as
  * full-fledged staffs, which'll be visually confusing. I'll fix it
- * soon.  
+ * soon.
  */
 
 void
@@ -85,7 +85,7 @@ set_rightmeasurenum (DenemoMovement * si)
 /**
  * Utility function for advancing a staff number and staff iterator to
  * the next primary voice, or to one off the end and NULL if there are
- * none remaining.  
+ * none remaining.
  */
 static void
 to_next_primary_voice (gint * staff_number, staffnode ** staff_iterator)
@@ -104,7 +104,7 @@ to_next_primary_voice (gint * staff_number, staffnode ** staff_iterator)
 /**
  * This function also has a side effect of bumping si->top_staff
  * up to the staff number of the next primary voice if si->top_staff
- * initially points to a nonprimary voice.  
+ * initially points to a nonprimary voice.
  */
 void
 set_bottom_staff (DenemoProject * gui)
@@ -118,6 +118,7 @@ set_bottom_staff (DenemoProject * gui)
 
   /* Bump up si->top_staff, if necessary.  */
   staff_iterator = g_list_nth (gui->movement->thescore, gui->movement->top_staff - 1);
+  if (!staff_iterator) {gui->movement->top_staff = 1;g_critical ("Bad top staff number %d",gui->movement->top_staff);  return;}//g_assert (staff_iterator);
   if (!((DenemoStaff *) staff_iterator->data)->voicecontrol & DENEMO_PRIMARY)
     to_next_primary_voice (&gui->movement->top_staff, &staff_iterator);
 
@@ -147,6 +148,7 @@ set_bottom_staff (DenemoProject * gui)
 void
 isoffleftside (DenemoProject * gui)
 {
+  if (gui->movement->currentmeasurenum == 0) gui->movement->currentmeasurenum = 1;
   if (gui->movement->currentmeasurenum >= gui->movement->leftmeasurenum)
     return;
   while (gui->movement->currentmeasurenum < gui->movement->leftmeasurenum)
@@ -181,13 +183,13 @@ isoffrightside (DenemoProject * gui)
 }
 
 /**
- * Move the viewable part of the score up 
+ * Move the viewable part of the score up
  *
  */
 void
 move_viewport_up (DenemoProject * gui)
 {
-  if(Denemo.non_interactive)  
+  if(Denemo.non_interactive)
     return;
   staffnode *staff_iterator;
 
@@ -252,18 +254,20 @@ move_viewport_down (DenemoProject * gui)
 
 /**
  * Sets the si->currentmeasurenum to the given value
- * if exists, making it the leftmost measure visible, extending selection or not
+ * if exists, making it the leftmost measure visible, not extending selection
  *
  */
 static gboolean
-goto_currentmeasurenum (DenemoProject * gui, gint dest, gint leftmeasurenum)
+goto_currentmeasurenum (gint dest, gint leftmeasurenum)
 {
+  DenemoProject *gui = Denemo.project;
   if ((dest > 0) && (dest <= (gint) (g_list_length (gui->movement->measurewidths))))
     {
       //gui->movement->leftmeasurenum = dest;
       gui->movement->currentmeasurenum = dest;
       if(leftmeasurenum)
         gui->movement->leftmeasurenum = leftmeasurenum;
+      set_rightmeasurenum (gui->movement);
       if ((dest < gui->movement->leftmeasurenum) || (dest > gui->movement->rightmeasurenum))
         center_viewport ();
       setcurrents (gui->movement);
@@ -285,7 +289,7 @@ goto_currentmeasurenum (DenemoProject * gui, gint dest, gint leftmeasurenum)
 gboolean
 set_currentmeasurenum (DenemoProject * gui, gint dest)
 {
-  return goto_currentmeasurenum (gui, dest, FALSE);
+  return goto_currentmeasurenum (dest, 0);
 }
 
 /**
@@ -296,7 +300,7 @@ set_currentmeasurenum (DenemoProject * gui, gint dest)
 gboolean
 moveto_currentmeasurenum (DenemoProject * gui, gint dest, gint leftmeasurenum)
 {
-  return goto_currentmeasurenum (gui, dest, leftmeasurenum);
+  return goto_currentmeasurenum (dest, leftmeasurenum);
 }
 
 
