@@ -48,6 +48,7 @@ struct callbackdata
   GtkWidget *immediateplayback;
   GtkWidget *measureswitchsound;
   GtkWidget *spillover;
+  GtkWidget *ignore_ties;
   GtkWidget *manualtypeset;
   GtkWidget *typesetrefresh;
   GtkWidget *typesettype;
@@ -281,6 +282,7 @@ set_preferences (struct callbackdata *cbdata)
     ASSIGNBOOLEAN (immediateplayback)
     ASSIGNINT (measureswitchsound)
     ASSIGNBOOLEAN (spillover)
+    ASSIGNBOOLEAN (ignore_ties)
     ASSIGNBOOLEAN (manualtypeset)
     ASSIGNINT (typesetrefresh)
     ASSIGNINT (typesettype)
@@ -308,6 +310,8 @@ set_preferences (struct callbackdata *cbdata)
     }
   if (prefs->learning)
     initialize_keystroke_help ();
+  if (prefs->tooltip_timeout == 0)
+    prefs->tooltip_timeout = 2000;
   /* Now write it all to denemorc */
   writeXMLPrefs (prefs);
 }
@@ -558,6 +562,7 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
     //  TEXTENTRY(_("Strict"), strictshortcuts)
   BOOLEANENTRY (_("Apply commands to selection if present"), applytoselection);
   BOOLEANENTRY (_("Spill notes over into next measure"), spillover);
+  BOOLEANENTRY (_("(Chord Entry) Do not fill in tied note pitches"), ignore_ties);
   BOOLEANENTRY (_("Allow Quick Setting of Shortcuts"), quickshortcuts);
 
 
@@ -567,8 +572,10 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
   BOOLEANENTRY (_("Turn on all Tooltips"), newbie);
   BOOLEANENTRY (_("Show Shortcuts Used"), learning);
   INTENTRY_LIMITS (_("Tooltip timeout in ms. (0 to use system preference)"), tooltip_timeout, 0, 1000000);
+#ifndef FAKE_TOOLTIPS
   INTENTRY_LIMITS (_("Tooltip browse timeout in ms"), tooltip_browse_timeout, 0, 1000000);
   INTENTRY_LIMITS (_("Tooltip browse mode timeout in ms"), tooltip_browse_mode_timeout, 0, 1000000);
+#endif
   /*
    * External (Helper) Programs
    */
@@ -641,7 +648,7 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
 
 
   BOOLEANENTRY (_("Play back entered notes immediately"), immediateplayback);
-  INTENTRY_LIMITS (_("MIDI key sound on measure end"), measureswitchsound, 0, 127);
+  INTENTRY_LIMITS (_("MIDI key sound on measure end\n  (0 = Off)"), measureswitchsound, 0, 127);
   INTENTRY_LIMITS (_("Pitch Spelling Channel"), pitchspellingchannel, 0, 15);
   INTENTRY_LIMITS (_("Pitch Spelling Program"), pitchspellingprogram, 0, 127);
 
